summaryrefslogtreecommitdiff
path: root/libdiskfs/diskfs.h
diff options
context:
space:
mode:
authorThomas Bushnell <thomas@gnu.org>1996-09-05 16:59:37 +0000
committerThomas Bushnell <thomas@gnu.org>1996-09-05 16:59:37 +0000
commit5145728f45d1a83ebe229ee38c4f2534a43c385f (patch)
tree48dfa16e2e256f1627e60d1f1d19dfcc9e6e46d2 /libdiskfs/diskfs.h
parent41476b24b860bc333ed99c3eb2b575193b111aa7 (diff)
*** empty log message ***
Diffstat (limited to 'libdiskfs/diskfs.h')
-rw-r--r--libdiskfs/diskfs.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/libdiskfs/diskfs.h b/libdiskfs/diskfs.h
index fe8374de..450e6e2e 100644
--- a/libdiskfs/diskfs.h
+++ b/libdiskfs/diskfs.h
@@ -203,11 +203,13 @@ extern struct node *diskfs_root_node;
filesystem server. */
extern char *diskfs_server_name;
-/* The user must define these variables. Set these to be the major, minor,
- and edit version numbers. */
-extern int diskfs_major_version;
-extern int diskfs_minor_version;
-extern int diskfs_edit_version;
+/* The user must define this variables. Set this to be the server
+ version number. */
+extern char *diskfs_server_version;
+
+/* The user may define this variable. Set this to be any additional
+ version specification that should be printed for --version. */
+extern char *diskfs_extra_version;
/* The user may define this variable. This should be nonzero iff the
filesystem format supports shortcutting symlink translation.